@@ -3,7 +3,7 @@ package App::ClusterSSH;
 use 5.008.004;
 use warnings;
 use strict;
-use version; our $VERSION = version->new('4.03_05');
+use version; our $VERSION = version->new('4.03_06');
 
 use Carp qw/cluck/;
 
@@ -1164,7 +1164,7 @@ sub toggle_active_state() {
 
 sub set_all_active() {
     my ($self) = @_;
-    logmsg( 2, "Setting all hosts to be active" );
+    $self->debug( 2, "Setting all hosts to be active" );
 
     foreach my $svr ( keys(%servers) ) {
         $servers{$svr}{active} = 1;
@@ -1174,7 +1174,7 @@ sub set_all_active() {
 
 sub set_half_inactive() {
     my ($self) = @_;
-    logmsg( 2, "Setting approx half of all hosts to inactive" );
+    $self->debug( 2, "Setting approx half of all hosts to inactive" );
 
     my (@keys) = keys(%servers);
     $#keys /= 2;
@@ -2124,8 +2124,6 @@ the code until this time.
 
 =item load_keyboard_map
 
-=item logmsg
-
 =item new
 
 =item open_client_windows
